@@ -86,7 +86,7 @@
 #define KJOBWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KJOBWIDGETS_NO_DEPRECATED
-#  define KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55900
+#  define KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
 #endif
 #ifdef KJOBWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KJOBWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KJOBWIDGETS_DEPRECATED_WARNINGS_SINCE KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KJOBWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55900
+#    define KJOBWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55d00
 #  endif
 #endif
 
@@ -180,7 +180,7 @@
 #define KJOBWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KJOBWIDGETS_NO_DEPRECATED
-#  define KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55900
+#  define KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
 #endif
 #ifdef KJOBWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KJOBWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -190,7 +190,7 @@
 #  ifdef KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KJOBWIDGETS_DEPRECATED_WARNINGS_SINCE KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KJOBWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55900
+#    define KJOBWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55d00
 #  endif
 #endif
 
